import os
import sys
import boto3
from botocore.client import Config
from dotenv import load_dotenv
import shutil


def install_zola():
    version = os.environ["INPUT_VERSION"]
    access_key = os.environ["INPUT_ACCESS_KEY"]
    secret_key = os.environ["INPUT_SECRET_KEY"]
    endpoint = os.environ["INPUT_ENDPOINT"]
    bucket = "omybucket"

    # 配置 S3 客户端
    s3 = boto3.client(
        "s3",
        endpoint_url=endpoint,
        aws_access_key_id=access_key,
        aws_secret_access_key=secret_key,
        config=Config(signature_version="s3v4"),
    )

    zola_filename = "zola-" + version

    try:
        s3.download_file(bucket, zola_filename, zola_filename)
        shutil.copy(zola_filename, "/usr/local/bin/zola")
        os.chmod("/usr/local/bin/zola", 0o755)
    except Exception as e:
        print(f"Error: {str(e)}")
        sys.exit(1)


if __name__ == "__main__":
    load_dotenv()
    install_zola()
